diff --git a/src/Subtext.Framework/Tracking/Notification.cs b/src/Subtext.Framework/Tracking/Notification.cs
index c44ecdbc6..10095afb3 100644
--- a/src/Subtext.Framework/Tracking/Notification.cs
+++ b/src/Subtext.Framework/Tracking/Notification.cs
@@ -35,6 +35,7 @@
#endregion
+using System;
using Subtext.Framework.Components;
using Subtext.Framework.Configuration;
using Subtext.Framework.Routing;
@@ -64,9 +65,12 @@ public static void Run(Entry entry, Blog blog, BlogUrlHelper urlHelper)
if (entry != null)
{
+ VirtualPath blogUrl = urlHelper.BlogUrl();
+ Uri fullyQualifiedUrl = blogUrl.ToFullyQualifiedUrl(blog);
+
var notify = new Notifier
{
- FullyQualifiedUrl = urlHelper.BlogUrl(),
+ FullyQualifiedUrl = fullyQualifiedUrl.AbsoluteUri,
BlogName = blog.Title,
Title = entry.Title,
PostUrl = urlHelper.EntryUrl(entry).ToFullyQualifiedUrl(blog),
diff --git a/src/Subtext.Framework/Tracking/TrackBackNotificationProxy.cs b/src/Subtext.Framework/Tracking/TrackBackNotificationProxy.cs
index 2c29abb49..27ab4b984 100644
--- a/src/Subtext.Framework/Tracking/TrackBackNotificationProxy.cs
+++ b/src/Subtext.Framework/Tracking/TrackBackNotificationProxy.cs
@@ -72,7 +72,7 @@ public static bool TrackBackPing(string pageText, Uri url, string title, Uri lin
return SendPing(trackBackUrl, parameters);
}
}
- return true;
+ return false;
}
private static bool SendPing(Uri trackBackItem, string parameters)
diff --git a/src/Subtext.Web/UI/Controls/ViewPost.cs b/src/Subtext.Web/UI/Controls/ViewPost.cs
index da59ca5e8..723408ee9 100644
--- a/src/Subtext.Web/UI/Controls/ViewPost.cs
+++ b/src/Subtext.Web/UI/Controls/ViewPost.cs
@@ -139,7 +139,7 @@ protected override void OnLoad(EventArgs e)
if (PingBack != null)
{
- PingBack.Text = TrackHelpers.GetPingPackTag(Url);
+ PingBack.Text = TrackHelpers.GetPingbackTag(Url, Entry);
}
if (TrackBack != null)
diff --git a/src/Subtext.Framework/Tracking/TrackHelpers.cs b/src/Subtext.Framework/Tracking/TrackHelpers.cs
index 7ef70cf0e..61ca3dd93 100644
--- a/src/Subtext.Framework/Tracking/TrackHelpers.cs
+++ b/src/Subtext.Framework/Tracking/TrackHelpers.cs
@@ -48,12 +48,16 @@ namespace Subtext.Framework.Tracking
///
public static class TrackHelpers
{
- //Text to insert into a file with pinkback service location
- public static string GetPingPackTag(BlogUrlHelper urlHelper)
+ //Text to insert into a file with pingback service location
+ public static string GetPingbackTag(BlogUrlHelper urlHelper, Entry entry)
{
+ VirtualPath blogUrl = urlHelper.BlogUrl();
+ Uri absoluteUrl = blogUrl.ToFullyQualifiedUrl(entry.Blog);
+
return string.Format(CultureInfo.InvariantCulture,
- "",
- urlHelper.BlogUrl());
+ "",
+ absoluteUrl.AbsoluteUri,
+ entry.Id);
}
//Body of text to insert into a post with Trackback